package sgc.portal.cs.cs0301.persistence;

import org.apache.ibatis.annotations.Mapper;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cs.cs0301.dto.CS03010002PSearch;
import sgc.portal.cs.cs0301.model.CS03010002P;
import sgc.portal.cs.cs0301.model.TcsDeftVo;
import sgc.portal.cs.cs0301.model.TcsDeftElpsVo;

import java.util.List;

@Mapper
public interface CS03010002PMapper {
	
	EasyHashMap<String, Object> getList(CS03010002PSearch search);
	
	List<EasyHashMap<String, Object>> getListElps(CS03010002PSearch search);
	
	List<EasyHashMap<String, Object>> getChrgrList(CS03010002PSearch search);
    
	/*접수처리*/
    int insertDeftElpsReceipt(TcsDeftElpsVo tcsDeftElps);
    int updateDeftReceipt(TcsDeftVo tcsDeft);
    
    /*반려처리*/
    int insertDeftElpsReject(TcsDeftElpsVo tcsDeftElps);
    int updateDeftReject(TcsDeftVo tcsDeft);
    
    /*작업완료처리*/
    int insertDeftElpsComplete(TcsDeftElpsVo tcsDeftElps);
    int updateDeftComplete(TcsDeftVo tcsDeft);
    
    /*최종완료처리*/
    int insertDeftElpsFinComplete(TcsDeftElpsVo tcsDeftElps);
    int updateDeftFinComplete(TcsDeftVo tcsDeft);
    
    /*작업경과등록*/
    int insertDeftElpsProcess(TcsDeftElpsVo tcsDeftElps);
    int updateDeftProcess(TcsDeftVo tcsDeft);
    String getProcess(CS03010002P cS03010002P);
    
    /*SMS전송처리*/
    int insertDeftElpsSms(TcsDeftElpsVo tcsDeftElpsSms);
    
    /*저장*/
    int updateDeft(TcsDeftVo tcsDeft);
    String getWorkWkiNo(TcsDeftVo tcsDeft);
    
    /*삭제*/
    int getDeftElpsCnt(TcsDeftVo tcsDeft);
    int deleteDeftElps(TcsDeftVo tcsDeft);
    int deleteDeft(TcsDeftVo tcsDeft);
    
}
